/**
<OWNER>Dane Foster</OWNER>
<ORGANIZATION>Equity Technology Group, Inc.</ORGANIZATION>
<YEAR>2001</YEAR>
Copyright (c) 2001, Equity Technology Group, Inc.
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
following conditions are met:
Redistributions of source code must retain the above copyright notice, this list of conditions and the following
disclaimer.  Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
following disclaimer in the documentation and/or other materials provided with the distribution.  Neither the name of
ETG or Dane Foster nor the names of its contributors may be used to endorse or promote products derived from this
software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**/
/**
 * Description:  Represents a MIME encoded object
 * @author       Dane Foster <mailto:dfoster@equitytg.com>
 * @version      1.0
 * @date         12.05.01
 */
// package com.equitytg.library.servlet;
package utils;

public class DataSource
{
    private String contentType, filename;
    private byte[] binary;

    /**
     * Creates a new DataSource object.
     *
     * @param   contentType The MIME type
     * @param   filename    The objects name.  This includes any path information
     * @param   bin         The binary contents of the MIME object
     */
    public DataSource( String contentType, String filename, byte[] bin )
    {
        this.contentType = contentType;
        this.filename = filename;
        this.binary = bin;
    }

    /**
     * Sets this object's content type.  The String should be in MIME format (i.e. image/jpeg)
     *
     * @param   type    The MIME type
     */
    public void setContentType( String type )
    {
        this.contentType = type;
    }

    /**
     * Sets this object's file name.  This should include any path information.
     * ex. /home/loser/images/you.jpg; c:\My Documents\My Pictures\you.gif
     *
     * @param   name    The file name
     */
    public void setFilename( String name )
    {
        this.filename = name;
    }

    /**
     * Sets this object's binary content
     *
     * @param   content   An array of bytes
     */
    public void setBinaryContent( byte[] content )
    {
        this.binary = content;
    }

    /**
     * @return  The MIME type of this DataSource object
     */
    public String getContentType()
    {
        return this.contentType;
    }

    /**
     * @return  The full file name including any path information
     */
    public String getFilename()
    {
        return this.filename;
    }

    /**
     * @return The object's name minus the path information or <code>null</code> if <code>getFilename()</code>
     *         returns <code>null</code>
     */
    public String getName()
    {
        String name = this.filename;
        if( null != name )
        {
            char separator = '/';
            int indx = name.indexOf( separator ); // try unix first
            if( -1 == indx )
            {
                separator = '\\'; // try Windows next
                indx = name.indexOf( separator );
            }
            if( -1 != indx )
                name = name.substring( name.lastIndexOf( separator ) + 1 );
        }
        return name;
    }

    /**
     * @return  The binary content of <code>this</code> MIME object
     */
    public byte[] getBinaryContent()
    {
        return this.binary;
    }
}
